Welcome to qpageview!
=====================

.. include:: ../../README.rst
    :start-line: 2

This manual documents `qpageview` version |release|.
Last update: |today|.

.. toctree::
    :maxdepth: 2
    :caption: Contents

    usage.rst
    advanced.rst
    interacting.rst
    rendering.rst
    modoverview.rst

.. toctree::
    :maxdepth: 1
    :caption: About

    installing.rst
    changelog.rst
    license.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
